=========
pywe-sign
=========

Wechat Sign Module for Python.

Installation
============

::

    pip install pywe-sign


Usage
=====

::

    from pywe_sign import calculate_signature, check_signature


Method
======

::

    def calculate_signature(params, api_key):

    def check_signature(params, api_key):

